<?php

namespace App\Api\Shared\Responses;

use App\Interfaces\SuccessfulResponseInterface;
use Exception;
use Illuminate\Http\JsonResponse;

class Success
{
    /**
     * Returns json response needed in controllers.
     *
     * @param string|SuccessfulResponseInterface $data Data need to be
     * contained in the response.
     * @param integer $code Response status code.
     * @param array $headers Headers needed to be set for the response.
     * @param integer $options Options.
     *
     * @return JsonResponse
     *
     * @throws Exception Throws an exception when status code does not
     * correspond or message property is not set in response data object.
     */
    public static function response(
        string|SuccessfulResponseInterface $data,
        int $code = 200,
        array $headers = [],
        $options = 0
    ): JsonResponse {
        if ($code < 200 || $code >= 300) {
            throw new Exception('Status code is invalid');
        }

        if ($data instanceof SuccessfulResponseInterface) {
            $dataArray = get_object_vars($data);

            if (!array_key_exists('message', $dataArray)) {
                throw new Exception('Message property does not exist');
            }

            foreach ($dataArray as $key => $value) {
                $response[$key] = $value;
            }

            return response()->json($response, $code, $headers, $options);
        }

        return response()->json(
            [
                'statusCode' => $code,
                'status'=> 'success',
                'data' => $data
            ],
            $code,
            $headers,
            $options
        );
    }
}
