<?php

namespace App\Http\Controllers\Api;

use App\Api\Shared\Responses\Error;
use App\Api\Shared\Responses\Success;
use App\Http\Controllers\Controller;
use App\Models\Attendance;
use App\Models\Tracking;
use Carbon\Carbon;
use Illuminate\Http\Request;

class AttendanceController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth:api');
    }

    public function checkStatus()
    {
        $user = auth()->user();

        $attendance = Attendance::where('user_id', auth()->user()->id)
            ->whereDate('created_at',  Carbon::today())
            ->first();

        $status = 'new';
        $checkInTime = null;
        $checkOutTime = null;

        if ($attendance != null) {
            if($attendance->status == 'checked_in') {
                $status = 'checkedin';
                $checkInTime = $attendance->check_in_time;
            } else {
                $status = 'checkedout';
                $checkInTime = $attendance->check_in_time;
                $checkOutTime = $attendance->check_out_time;
            }
        }

        return response()->json([
            'statusCode' => 200,
            'status' => 'success',
            'data' => [
                'userStatus'=> $user->status,
                'status' => $status, // 'new', 'present', 'checkedout
                'checkInAt' => $checkInTime,
                'checkOutAt' => $checkOutTime
            ],
        ]);
    }

    public function checkInOut(Request $request){
        $status = $request->status;
        $latitude = $request->latitude;
        $longitude = $request->longitude;
        $isMock = $request->isMock;
        $batteryPercentage = $request->batteryPercentage;
        $isGpsOn = $request->isLocationOn;
        $isWifiOn = $request->isWifiOn;
        $signalStrength = $request->signalStrength;

        if($status == null){
            return Error::response('Status is required');
        }

        if($status != 'checkin' && $status != 'checkout'){
            return Error::response('Invalid status');
        }

        if($latitude == null){
            return Error::response('Latitude is required');
        }

        if($longitude == null){
            return Error::response('Longitude is required');
        }

        $attendance = Attendance::whereDate('created_at',Carbon::today())
            ->where('user_id', auth()->user()->id)
            ->first();

        if($attendance != null && $status == 'checkin') {
            return Error::response('Already checked in');
        }

        if($attendance == null && $status == 'checkout') {
            return Error::response('Not checked in');
        }

        if($status == 'checkin'){
            if($attendance ==null){
                $createdAttendance = Attendance::create([
                    'user_id' => auth()->user()->id,
                    'check_in_time' => date('Y-m-d H:i:s'),
                    'status' => 'checked_in',
                ]);

                Tracking::create([
                    'attendance_id' => $createdAttendance->id,
                    'latitude' => $latitude,
                    'longitude' => $longitude,
                    'is_mock' => $isMock,
                    'battery_percentage' => $batteryPercentage,
                    'is_gps_on' => $isGpsOn,
                    'is_wifi_on' => $isWifiOn,
                    'signal_strength' => $signalStrength,
                    'type' => 'checked_in',
                    'accuracy' => 100
                ]);
            }
        }else{
            if($attendance != null){
                $attendance->status = 'checked_out';
                $attendance->check_out_time = date('Y-m-d H:i:s');
                $attendance->save();

                Tracking::create([
                    'attendance_id' => $attendance->id,
                    'latitude' => $latitude,
                    'longitude' => $longitude,
                    'is_mock' => $isMock,
                    'battery_percentage' => $batteryPercentage,
                    'is_gps_on' => $isGpsOn,
                    'is_wifi_on' => $isWifiOn,
                    'signal_strength' => $signalStrength,
                    'type' => 'checked_out',
                    'accuracy' => 100
                ]);
            }
        }

        return Success::response('Status updated successfully');
    }

    public function statusUpdate(Request $request){
        $status = $request->status;
        $accuracy = $request->accuracy;
        $activity = $request->activity;
        $latitude = $request->latitude;
        $longitude = $request->longitude;
        $isMock = $request->isMock;
        $batteryPercentage = $request->batteryPercentage;
        $isGpsOn = $request->isGPSOn;
        $isWifiOn = $request->isWifiOn;
        $signalStrength = $request->signalStrength;


        if($status == null){
            return Error::response('Status is required');
        }

        if($latitude == null){
            return Error::response('Latitude is required');
        }

        if($longitude == null){
            return Error::response('Longitude is required');
        }

        $attendance = auth()->user()->attendances()->whereDate('created_at', Carbon::now())->first();

        if($attendance == null){
            return Error::response('Not checked in');
        }

        Tracking::create([
            'attendance_id' => $attendance->id,
            'latitude' => $latitude,
            'longitude' => $longitude,
            'is_mock' => $isMock,
            'battery_percentage' => $batteryPercentage,
            'is_gps_on' => $isGpsOn,
            'is_wifi_on' => $isWifiOn,
            'signal_strength' => $signalStrength,
            'type' => $status == 'still' ? 'still' : 'travelling',
            'activity' => $activity,
            'accuracy' => $accuracy
        ]);

        return Success::response('Status updated successfully');
    }
}
