<?php

namespace App\Http\Controllers;

use App\Models\Shift;
use App\Models\Team;
use App\Models\User;
use Hash;
use Illuminate\Http\Request;
use RuntimeException;
use Sentinel;

class EmployeeController extends Controller
{
    public function index()
    {
        $role = Sentinel::findRoleBySlug('user');

        $employeeIds = $role->users()->with('roles')
            ->select('id')
            ->get();

        $ids = array_column($employeeIds->toArray(), 'id');

        $employees = User::whereIn('id', $ids)
        ->with('team')
        ->get();

        app('debugbar')->info($role);

        return view('employee.index', compact('employees'));
    }

    public function create()
    {
        $managerRole = Sentinel::findRoleBySlug('manager');

        $managers = $managerRole->users()->with('roles')
            ->select('id', 'first_name', 'last_name')
            ->get();

        $shifts = Shift::where('status', '=','active')
            ->select('id', 'title')
            ->get();

        $teams = Team::where('status', '=','active')
            ->select('id', 'name')
            ->get();

        return view('employee.create', compact('managers', 'shifts', 'teams'));
    }

    public function show($id)
    {
        $user = User::where('id', $id)
            ->with('team')
            ->with('shift')
            ->with('userDevice')
            ->first();

        $managerName = User::where('id', $user->parent_id)
            ->select('first_name', 'last_name')
            ->first();

        return view('employee.show', compact('user', 'managerName'));
    }

    public function edit($id)
    {
        $user = User::findOrFail($id);

        $managerRole = Sentinel::findRoleBySlug('manager');

        $managers = $managerRole->users()->with('roles')
            ->select('id', 'first_name', 'last_name')
            ->get();

        $managers = $managerRole->users()->with('roles')
            ->select('id', 'first_name', 'last_name')
            ->get();

        $shifts = Shift::where('status', '=','active')
            ->select('id', 'title')
            ->get();

        $teams = Team::where('status', '=','active')
            ->select('id', 'name')
            ->get();
        return view('employee.edit', compact('user', 'managers', 'shifts', 'teams'));
    }

    public function update(Request $request, $id)
    {
        if(env('DEMO_MODE')){
            return redirect()->route('employee.show',['id' => $id])->with('error', 'You can not change status in demo mode');
        }
        $rules = [
            'email' => 'email|unique:users,email,'.$id,
            'phoneNumber' => 'required|unique:users,phone_number,'.$id,

            'firstName' => 'required',
            'lastName' => 'required',
            'address' => 'required',
            'parentId' => 'required',
            'shiftId' => 'required',
            'teamId' => 'required',
            'designation' => 'required',
        ];

        $customMessages = [
            'parentId.required' => 'Manager is required',
            'shiftId.required' => 'Shift is required',
            'teamId.required' => 'Team is required',
        ];

        $this->validate($request, $rules,$customMessages);

        $user = User::findOrFail($id);

        if($user->email != $request->email){
            $user->email = request()->email;
        }

        if($user->phone_number != $request->phoneNumber){
            $user->phone_number = $request->phoneNumber;
        }

        if($user->first_name != $request->firstName){
            $user->first_name = $request->firstName;
        }

        if($user->last_name != $request->lastName){
            $user->last_name = $request->lastName;
        }

        if ($user->gender != $request->gender){
            $user->gender = $request->gender;
        }

        if ($user->dob != $request->dob){
            $user->dob = $request->dob;
        }

        if ($user->unique_id != $request->uniqueId){
            $user->unique_id = $request->uniqueId;
        }

        if ($user->alternate_number != $request->alternateNumber){
            $user->alternate_number = $request->alternateNumber;
        }

        if ($user->address != $request->address){
            $user->address = $request->address;
        }

        if ($user->parent_id != $request->parentId){
            $user->parent_id = $request->parentId;
        }

        if ($user->shift_id != $request->shiftId){
            $user->shift_id = $request->shiftId;
        }

        if ($user->team_id != $request->teamId){
            $user->team_id = $request->teamId;
        }

        if ($user->date_of_joining != $request->dateOfJoining){
            $user->date_of_joining = $request->dateOfJoining;
        }

        if ($user->designation != $request->designation){
            $user->designation = $request->designation;
        }

        if ($user->base_salary != $request->baseSalary){
            $user->base_salary = $request->baseSalary;
        }


        if ($user->primary_sales_target != $request->primarySalesTarget){
            $user->primary_sales_target = $request->primarySalesTarget;
        }

        if ($user->secondary_sales_target != $request->secondarySalesTarget){
            $user->secondary_sales_target = $request->secondarySalesTarget;
        }

        if ($user->available_leaves != $request->availableLeaves){
            $user->available_leaves = $request->availableLeaves;
        }

        $user->save();

        return redirect()->route('employee.index')->with('success', 'Employee updated successfully');
    }

    public function store(Request $request)
    {
        $rules = [
            'userName' => 'required|unique:users,user_name',
            'useDefaultPassword' => 'required',
            'email' => 'email|unique:users,email',
            'phoneNumber' => 'required|unique:users,phone_number',

            'firstName' => 'required',
            'lastName' => 'required',
            'address' => 'required',
            'parentId' => 'required',
            'shiftId' => 'required',
            'teamId' => 'required',
            'designation' => 'required',
        ];

        $customMessages = [
            'parentId.required' => 'Manager is required',
            'shiftId.required' => 'Shift is required',
            'teamId.required' => 'Team is required',
        ];

        $this->validate(request(), $rules,$customMessages);

        $newUser = array(
            'user_name' => $request->userName,
            'password'    => Hash::make($request->useDefaultPassword == null ? $request->password : "123456"),
            'phone_number'=> $request->phoneNumber,
            'email'       => $request->email,

            'first_name'  => $request->firstName,
            'last_name'   => $request->lastName,
            'gender' => $request->gender,
            'dob' => $request->dob,
            'unique_id' => $request->uniqueId,
            'alternate_number'  => $request->alternateNumber,
            'address' => $request->address,

            'parent_id' =>$request->parentId,
            'shift_id' => $request->shiftId,
            'team_id' =>$request->teamId,
            'date_of_joining' => $request->dateOfJoining,
            'designation' => $request->designation,
            'base_salary' => $request->baseSalary,
            'primary_sales_target' => $request->primarySalesTarget,
            'secondary_sales_target' => $request->secondarySalesTarget,
            'available_leaves' => $request->availableLeaves,
        );

        $user = User::create($newUser);


        $userRole = Sentinel::findRoleBySlug('user');

        $userRole->users()->attach($user);

        return redirect()->route('employee.index')->with('success', 'Employee created successfully');
    }

    public function destroy($id)
    {
        if(env('DEMO_MODE')){
            return redirect()->route('account.show',['id' => $id])->with('error', 'You can not change status in demo mode');
        }
        $employee = User::findOrFail($id);
        $employee->delete();
        return redirect()->route('employee.index');
    }

    public function changeStatus(Request $request)
    {
        if(env('DEMO_MODE')){
            return redirect()->route('employee.show',['id' => $request->id])->with('error', 'You can not change status in demo mode');
        }
        $employee = User::findOrFail($request->id);
        if($employee->status == 'active'){
            $employee->status = 'inactive';
        }else{
            $employee->status = 'active';
        }
        $employee->save();

        return redirect()->route('employee.show', $request->id)->with('success', 'Employee status changed successfully');
    }


}
