<?php

namespace App\Http\Controllers;

use App\Models\Settings;
use Illuminate\Http\Request;

class SettingsController extends Controller
{
    public function index()
    {
        $settings = Settings::first();

        return view('settings.index', compact('settings'));
    }

    public function updateBasicSettings(Request $request)
    {
        if(env('DEMO_MODE')){
            return redirect()->route('settings.index')->with('error', 'This action is disabled in demo mode');
        }

        $appName = $request->appName;
        $appVersion = $request->appVersion;
        $country = $request->country;
        $phoneCountryCode = $request->phoneCountryCode;
        $currency = $request->currency;
        $currencySymbol = $request->currencySymbol;
        $distanceUnit = $request->distanceUnit;

        if($appName == null ){
            return redirect()->route('settings.index')->with('error', 'App Name is required');
        }

        if($appVersion == null ){
            return redirect()->route('settings.index')->with('error', 'App Version is required');
        }

        if($country == null ){
            return redirect()->route('settings.index')->with('error', 'Country is required');
        }

        if($phoneCountryCode == null ){
            return redirect()->route('settings.index')->with('error', 'Phone Country Code is required');
        }

        if($currency == null ){
            return redirect()->route('settings.index')->with('error', 'Currency is required');
        }

        if($currencySymbol == null ){
            return redirect()->route('settings.index')->with('error', 'Currency Symbol is required');
        }

        if($distanceUnit == null ){
            return redirect()->route('settings.index')->with('error', 'Distance Unit is required');
        }


        $settings = Settings::first();
        $settings->app_name = $appName;
        $settings->app_version = $appVersion;
        $settings->country = $country;
        $settings->phone_country_code = $phoneCountryCode;
        $settings->currency = $currency;
        $settings->currency_symbol = $currencySymbol;
        $settings->distance_unit = $distanceUnit == 'KM' ? 'km' : 'miles';
        $settings->save();

        return redirect()->route('settings.index')->with('success', 'Settings Updated Successfully');
    }

    public function updateDashboardSettings(Request $request){
        if(env('DEMO_MODE')){
            return redirect()->route('settings.index')->with('error', 'This action is disabled in demo mode');
        }

        $offlineCheckTimeType = $request->offlineCheckTimeType;
        $offlineCheckTime = $request->offlineCheckTime;

        if($offlineCheckTimeType == null ){
            return redirect()->route('settings.index')->with('error', 'Offline Check Time Type is required');
        }

        if($offlineCheckTime == null ){
            return redirect()->route('settings.index')->with('error', 'Offline Check Time is required');
        }

        $settings = Settings::first();
        $settings->offline_check_time_type = $offlineCheckTimeType;
        $settings->offline_check_time = $offlineCheckTime;
        $settings->save();

        return redirect()->route('settings.index')->with('success', 'Settings Updated Successfully');
    }

    public function updateMobileAppSettings(Request $request){
        if(env('DEMO_MODE')){
            return redirect()->route('settings.index')->with('error', 'This action is disabled in demo mode');
        }
        $mobileAppVersion = $request->mobileAppVersion;
        $privacyPolicyLink = $request->privacyPolicyLink;
        $locationUpdateIntervalType = $request->locationUpdateIntervalType;
        $locationUpdateInterval = $request->locationUpdateInterval;

        if($mobileAppVersion == null ){
            return redirect()->route('settings.index')->with('error', 'Mobile App Version is required');
        }

        if($privacyPolicyLink == null ){
            return redirect()->route('settings.index')->with('error', 'Privacy Policy Link is required');
        }

        if($locationUpdateIntervalType == null ){
            return redirect()->route('settings.index')->with('error', 'Location Update Interval Type is required');
        }

        if($locationUpdateInterval == null ){
            return redirect()->route('settings.index')->with('error', 'Location Update Interval is required');
        }

        $settings = Settings::first();
        $settings->m_app_version = $mobileAppVersion;
        $settings->privacy_policy_url = $privacyPolicyLink;
        $settings->m_location_update_time_type = $locationUpdateIntervalType;
        $settings->m_location_update_interval = $locationUpdateInterval;
        $settings->save();

        return redirect()->route('settings.index')->with('success', 'Settings Updated Successfully');
    }

    public function updateMapSettings(Request $request){

        if(env('DEMO_MODE')){
            return redirect()->route('settings.index')->with('error', 'This action is disabled in demo mode');
        }
        $latitude = $request->latitude;
        $longitude = $request->longitude;
        $mapZoomLevel = $request->mapZoomLevel;

        if($latitude == null ){
            return redirect()->route('settings.index')->with('error', 'Latitude is required');
        }

        if($longitude == null ){
            return redirect()->route('settings.index')->with('error', 'Longitude is required');
        }

        if($mapZoomLevel == null ){
            return redirect()->route('settings.index')->with('error', 'Map Zoom Level is required');
        }

        $settings = Settings::first();
        $settings->center_latitude = $latitude;
        $settings->center_longitude = $longitude;
        $settings->map_zoom_level = $mapZoomLevel;
        $settings->save();

        return redirect()->route('settings.index')->with('success', 'Settings Updated Successfully');
    }
}
