<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('shifts', function (Blueprint $table) {
        $table->id();
        $table->string('title');
        $table->string('description')->nullable();
        $table->time('start_time');
        $table->time('end_time');
        $table->enum('status', ['active', 'inactive'])->default('active');
        $table->boolean('sunday')->default(false);
        $table->boolean('monday')->default(false);
        $table->boolean('tuesday')->default(false);
        $table->boolean('wednesday')->default(false);
        $table->boolean('thursday')->default(false);
        $table->boolean('friday')->default(false);
        $table->boolean('saturday')->default(false);
        $table->unsignedBigInteger('created_by_id')->nullable();
        $table->unsignedBigInteger('updated_by_id')->nullable();
        $table->timestamps();
       });

        Schema::create('teams', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->string('description')->nullable();
            $table->enum('status', ['active', 'inactive']) ->default('active');
            $table->boolean('is_chat_enabled')->default(true);
            $table->unsignedBigInteger('created_by_id')->nullable();
            $table->unsignedBigInteger('updated_by_id')->nullable();
            $table->timestamps();
        });

        Schema::create('persistences', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('user_id')->unsigned();
            $table->string('code');
            $table->timestamps();

            $table->unique('code');
        });

        Schema::create('throttle', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('user_id')->unsigned()->nullable();
            $table->string('type');
            $table->string('ip')->nullable();
            $table->timestamps();

            $table->index('user_id');
        });

        Schema::create('users', function (Blueprint $table) {
            $table->id();
            $table->string('first_name');
            $table->string('last_name');
            $table->string('user_name')->nullable()->unique();
            $table->string('email')->nullable()->unique();
            $table->string('designation')->nullable();
            $table->string('phone_number')->unique();
            $table->timestamp('email_verified_at')->nullable();
            $table->string('password');
            // 0 = super admin // 1 = admin // 2 = employee // 3 = manager // 4 = supervisor // 5 = accounts
            // 6 = sales // 7 = intern // 8 = HR
            $table->string('type')->nullable();
            $table->text('permissions')->nullable();
            $table->timestamp('last_login')->nullable();

            $table->unsignedBigInteger('parent_id')->nullable();
            $table->string('unique_id')->nullable();
            $table->string('profile_picture')->nullable();
            $table->string('address')->nullable();
            $table->string('alternate_number')->nullable();
            $table->date('dob')->nullable();
            $table->date('date_of_joining')->nullable();
            $table->decimal('base_salary', 10, 2)->nullable();
            $table->decimal('hourly_rate', 10, 2)->nullable();
            $table->decimal('overtime_rate', 10, 2)->nullable();
            $table->unsignedBigInteger('created_by_id')->nullable();

            $table->integer('available_leaves')->nullable();
            $table->decimal('primary_sales_target', 10, 2)->nullable();
            $table->decimal('secondary_sales_target', 10, 2)->nullable();

            $table->unsignedBigInteger('shift_id')->nullable();
            $table->foreign('shift_id')->references('id')->on('shifts')->onDelete('cascade');

            $table->unsignedBigInteger('team_id')->nullable();
            $table->foreign('team_id')->references('id')->on('teams')->onDelete('cascade');

            $table->enum('status', ['active', 'inactive','banned'])->default('active');
            $table->enum('gender',['male','female','unknown'])->default('unknown');

            $table->rememberToken();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('users');
        Schema::dropIfExists('shifts');
        Schema::dropIfExists('teams');
    }
};
