<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('settings', function (Blueprint $table) {
            $table->id();
            $table->string('app_name');
            $table->string('app_version');
            $table->string('country');
            $table->string('phone_country_code');
            $table->string('timezone');
            $table->string('currency');
            $table->string('currency_symbol');
            $table->enum('distance_unit', ['km', 'miles'])->default('km');

            //Checking
            $table->enum('offline_check_time_type', ['minutes', 'seconds'])->default('minutes');
            $table->integer('offline_check_time')->default(15);

            //Mobile App Settings
            $table->string('m_app_version');
            $table->enum('m_location_update_time_type', ['minutes', 'seconds'])->default('minutes');
            $table->integer('m_location_update_interval');
            $table->string('privacy_policy_url');

            //Map Settings
            $table->string('map_provider')->default('google');
            $table->integer('map_zoom_level');
            $table->decimal('center_latitude', 10, 8);
            $table->decimal('center_longitude', 11, 8);
            $table->boolean('is_ai_chat_enabled')->default(false);

            $table->unsignedBigInteger('created_by_id')->nullable();
            $table->unsignedBigInteger('updated_by_id')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('settings');
    }
};
