<?php

namespace Database\Seeders;

use App\Models\Client;
use App\Models\ExpenseType;
use App\Models\Holiday;
use App\Models\LeaveType;
use App\Models\Shift;
use App\Models\Team;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;

class DemoDataSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        DB::statement('SET FOREIGN_KEY_CHECKS=0;');
        DB::table('leave_types')->truncate();
        DB::table('expense_types')->truncate();
        DB::table('clients')->truncate();
        DB::table('shifts')->truncate();
        DB::table('teams')->truncate();
        DB::table('holidays')->truncate();
        DB::statement('SET FOREIGN_KEY_CHECKS=1;');

        //Leave Types
        LeaveType::create([
            'name' => 'Casual Leave',
            'description' => 'Casual Leave',
            'is_img_required' => 0,
            'status' => 1
        ]);

        LeaveType::create([
            'name' => 'Sick Leave',
            'description' => 'Sick Leave',
            'is_img_required' => 1,
            'status' => 1
        ]);

        LeaveType::create([
            'name' => 'Other Leave',
            'description' => 'Other Leave',
            'is_img_required' => 1,
            'status' => 1
        ]);

        $this->command->info('Demo Leave Type Seeded Successfully');

        //Expense Types
        ExpenseType::create([
            'name' => 'Travel',
            'description' => 'Travel',
            'is_img_required' => 1,
            'status' => 1
        ]);

        ExpenseType::create([
            'name' => 'Food',
            'description' => 'Food',
            'is_img_required' => 1,
            'status' => 1
        ]);

        ExpenseType::create([
            'name' => 'Other',
            'description' => 'Other',
            'is_img_required' => 0,
            'status' => 1
        ]);

        $this->command->info('Demo Expense Type Seeded Successfully');

        //Clients
        Client::create([
            'name' => 'Test Solution',
            'address' => 'India',
            'phone' => '1234567890',
            'email' => 'test@czappstudio.com',
            'city'=> 'chennai',
            'state'=> 'Tamil Nadu',
            'radius'=> 100,
            'latitude'=> 23.613541,
            'longitude'=> 58.594109,
            'status' => 'active'
        ]);

        Client::create([
            'name' => 'Test Solution 2',
            'address' => 'India',
            'phone' => '1234567890',
            'email' => 'test2@czappstudio.com',
            'city'=> 'chennai',
            'state'=> 'Tamil Nadu',
            'radius'=> 100,
            'latitude'=> 23.613541,
            'longitude'=> 58.594109,
            'status' => 'active'
        ]);

        $this->command->info('Demo Client Seeded Successfully');


        //Shifts
        Shift::create(
            [
                'title' => 'Morning Shift',
                'description' => 'Morning Shift',
                'start_time' => '09:00:00',
                'end_time' => '17:00:00',
                'status' => 'active',
                'sunday' => 0,
                'monday' => 1,
                'tuesday' => 1,
                'wednesday' => 1,
                'thursday' => 1,
                'friday' => 1,
                'saturday' => 0,

            ],
            [
                'title' => 'Night Shift',
                'description' => 'Night Shift',
                'start_time' => '17:00:00',
                'end_time' => '09:00:00',
                'status' => 'active',
                'sunday' => 0,
                'monday' => 1,
                'tuesday' => 1,
                'wednesday' => 1,
                'thursday' => 1,
                'friday' => 1,
                'saturday' => 0,
            ]
        );

        $this->command->info('Demo Shift Seeded Successfully');

        //Teams
        Team::create([
            'name' => 'Default Team',
            'description' => 'Team 1',
            'status' => 1,
            'is_chat_enabled' => 1
        ]);

        Team::create([
            'name' => 'Team 2',
            'description' => 'Team 2',
            'status' => 1,
            'is_chat_enabled' => 1
        ]);

        Team::create([
            'name' => 'Team 3',
            'description' => 'Team 3',
            'status' => 1,
            'is_chat_enabled' => 1
        ]);

        $this->command->info('Demo Team Seeded Successfully');

        //Holidays
        Holiday::insert([
            'name' => 'New Year',
            'description' => 'New Year',
            'date' => '2024-01-01',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Republic Day',
            'description' => 'Republic Day',
            'date' => '2024-01-26',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Holi',
            'description' => 'Holi',
            'date' => '2024-03-21',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Good Friday',
            'description' => 'Good Friday',
            'date' => '2024-04-19',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Eid al-Fitr',
            'description' => 'Eid al-Fitr',
            'date' => '2024-06-05',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Independence Day',
            'description' => 'Independence Day',
            'date' => '2024-08-15',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Gandhi Jayanti',
            'description' => 'Gandhi Jayanti',
            'date' => '2024-10-02',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Diwali',
            'description' => 'Diwali',
            'date' => '2024-10-27',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'Christmas',
            'description' => 'Christmas',
            'date' => '2024-12-25',
            'status' => 1
        ]);

        Holiday::insert([
            'name' => 'New Year',
            'description' => 'New Year',
            'date' => '2025-01-01',
            'status' => 1
        ]);

        $this->command->info('Demo Holiday Seeded Successfully');

        $this->command->info('----Demo Data Seeded Successfully----');
    }
}
