@php
    $title = 'Edit Employee';
    $settings = \App\Models\Settings::first();
@endphp
@section('title') {{$title}} @endsection
@extends('layout')
@section('main-content')

    <form action="{{route('employee.update',['id'=>$user->id])}}" method="post">
        @csrf
        <div class="card shadow">
            <div class="card-body">
                <div class="card card-primary">
                    <div class="card-header">
                        <h6>Login Details</h6>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="form-group col-md-4">
                                <label for="userName" class="control-label">User Name</label>
                                <input id="userName" disabled name="userName" class="form-control" value="{{$user->user_name}}"/>
                                <span class="text-danger">{{ $errors->first('userName', ':message') }}</span>
                            </div>
                            <div class="row mt-2">
                                <div class="form-group col-md-6">
                                    <label for="phoneNumber" class="control-label">Phone Number</label>
                                    <input id="phoneNumber" name="phoneNumber" type="number" class="form-control" value="{{$user->phone_number}}"/>
                                    <span class="text-danger">{{ $errors->first('phoneNumber', ':message') }}</span>
                                </div>
                                <div class="form-group col-md-6">
                                    <label for="email" class="control-label">Email</label>
                                    <input id="email" name="email" type="email" class="form-control" value="{{$user->email}}" />
                                    <span class="text-danger">{{ $errors->first('email', ':message') }}</span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card card-primary mt-2">
                    <div class="card-header">
                        <h6> Personal Details</h6>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="form-group col-md-3 mb-3">
                                <label for="firstName" class="control-label">First Name</label>
                                <input id="firstName" name="firstName" class="form-control" value="{{$user->first_name}}"/>
                                <span class="text-danger">{{ $errors->first('firstName', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="lastName" class="control-label">Last Name</label>
                                <input id="lastName" name="lastName" class="form-control" value="{{$user->last_name}}"/>
                                <span class="text-danger">{{ $errors->first('lastName', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="gender" class="control-label">Gender</label>
                                <select id="gender" name="gender" class="form-select mb-3">
                                    <option {{$user->gender=='male'? 'selected':''}} value="male">Male</option>
                                    <option {{$user->gender=='female'? 'selected':''}} value="female">Female</option>
                                    <option {{$user->gender=='unknown'? 'selected':''}} value="unknown">Unknown</option>
                                </select>
                                <span class="text-danger">{{ $errors->first('gender', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="dob" class="control-label">Date of birth</label>
                                <input id="dob" name="dob" type="date" class="form-control" value="{{$user->dob}}"/>
                                <span class="text-danger">{{ $errors->first('dob', ':message') }}</span>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="form-group col-md-3 mb-3">
                                <label for="uniqueId" class="control-label">Unique Id</label>
                                <input id="uniqueId" name="uniqueId" class="form-control" value="{{$user->unique_id}}"/>
                                <span class="text-danger">{{ $errors->first('uniqueId', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="alternateNumber" class="control-label">Alternate Number</label>
                                <input id="alternateNumber" name="alternateNumber" type="number" class="form-control" value="{{$user->alternate_number}}"/>
                                <span class="text-danger">{{ $errors->first('alternateNumber', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-6 mb-3">
                                <label for="address" class="control-label">Address</label>
                                <input id="address" name="address" class="form-control" value="{{$user->address}}"/>
                                <span class="text-danger">{{ $errors->first('address', ':message') }}</span>
                            </div>

                        </div>
                    </div>
                </div>
                <div class="card card-primary mt-2">
                    <div class="card-header">
                        <h6> Work Details</h6>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="form-group col-md-3 mb-3">
                                <label id="parentId" class="control-label">Manager</label>
                                <select id="parentId" name="parentId" data-choices="data-choices"
                                        data-options='{"removeItemButton":true,"placeholder":true}'
                                        class="form-select mb-3">
                                    <option value="">Please select a manager</option>
                                    @foreach($managers as $manager)
                                        <option {{$user->parent_id==$manager->id? 'selected':''}}
                                            value="{{$manager->id}}">{{$manager->first_name.' '.$manager->last_name}}</option>
                                    @endforeach
                                </select>
                                <span class="text-danger">{{ $errors->first('parentId', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label id="shiftId" class="control-label">Shift</label>
                                <select id="shiftId" name="shiftId" data-choices="data-choices"
                                        data-options='{"removeItemButton":true,"placeholder":true}'
                                        class="form-select mb-3">
                                    <option value="">Please select a shift</option>
                                    @foreach($shifts as $shift)
                                        <option {{$user->shift_id == $shift->id ? 'selected' : ''}} value="{{$shift->id}}">{{$shift->title}}</option>
                                    @endforeach
                                </select>
                                <span class="text-danger">{{ $errors->first('shiftId', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="teamId" class="control-label">Team</label>
                                <select id="teamId" name="teamId" data-choices="data-choices"
                                        data-options='{"removeItemButton":true,"placeholder":true}'
                                        class="form-select mb-3">
                                    <option value="">Please select a team</option>
                                    @foreach($teams as $team)
                                        <option {{$user->team_id == $team->id ? 'selected' : ''}} value="{{$team->id}}">{{$team->name}}</option>
                                    @endforeach
                                </select>
                                <span class="text-danger">{{ $errors->first('teamId', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="dateOfJoin" class="control-label">Date Of Join</label>
                                <input id="dateOfJoin" name="dateOfJoin" type="date" class="form-control" value="{{$user->date_of_joining}}"/>
                                <span class="text-danger">{{ $errors->first('dateOfJoin', ':message') }}</span>

                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="form-group col-md-3 mb-3">
                                <label for="designation" class="control-label">Designation</label>
                                <input id="designation" name="designation" class="form-control" value="{{$user->designation}}"/>
                                <span class="text-danger">{{ $errors->first('designation', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="baseSalary" class="control-label">Base Salary</label>
                                <input id="baseSalary" name="baseSalary" type="number" class="form-control" value="{{$user->base_salary}}"/>
                                <span class="text-danger">{{ $errors->first('baseSalary', ':message') }}</span>

                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="primarySalesTarget" class="control-label">Primary Sales Target</label>
                                <input id="primarySalesTarget" name="primarySalesTarget" type="number"
                                       class="form-control" value="{{$user->primary_sales_target}}"/>
                                <span class="text-danger">{{ $errors->first('primarySalesTarget', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="secondarySalesTarget" class="control-label">Secondary Sales Target</label>
                                <input id="secondarySalesTarget" name="secondarySalesTarget" type="number"
                                       class="form-control" value="{{$user->secondary_sales_target}}"/>
                                <span
                                    class="text-danger">{{ $errors->first('secondarySalesTarget', ':message') }}</span>
                            </div>
                            <div class="form-group col-md-3 mb-3">
                                <label for="availableLeaveCount" class="control-label">Available Leave Count</label>
                                <input id="availableLeaveCount" name="availableLeaveCount" type="number"
                                       class="form-control" value="{{$user->available_leaves}}"/>
                                <span class="text-danger">{{ $errors->first('availableLeaveCount', ':message') }}</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="card-footer">
                <div class="form-group">
                    <button type="submit" class="btn btn-primary">Save changes</button>
                </div>
            </div>
        </div>

    </form>
@endsection
